Description Usage Arguments Value
generate a random face spline from the pfd face space
1 | gen_face_spline(coef = NULL, fixed_pcs = 0)
|
the |
number of leading principal components to fix at zero. |
an instance of class face_spline
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.